@@ -103,8 +103,10 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 	long val;
 #endif
 
+	static char null[1] = {0};
+
 	unsigned dcount = 0, pos;
-	const char *cp;
+	char *cp;
 	char *ep;
 	char idbuf[32];
 	unsigned len;
@@ -233,7 +235,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 		if(pos < strlen(sym->data))
 			cp = sym->data + pos;
 		else
-			cp = "";
+			cp = null;
 		script::copy(cp, tp, script::sizing);
 	}
 	else if(String::equal(id, "offset/", 7)) {
@@ -268,7 +270,7 @@ offset:
 		if(cp)
 			++cp;
 		else
-			cp = "";
+			cp = null;
 		while(dcount++ < script::decimals && pos < script::sizing) {
 			if(*cp && isdigit(*cp))
 				tp[pos++] = *(cp++);
@@ -310,7 +312,7 @@ search:
 		else if(NULL != (cp = strstr(sym->data, idbuf)))
 			cp = cp + len;
 		else
-			cp = "";
+			cp = null;
 		dcount = 0;
 		if(*cp == '\"') {
 			quote = *cp;
